@@ -163,6 +163,8 @@ typedef enum {
     FILE_TYPE_GBM_BACKEND_LIB,
     FILE_TYPE_GBM_BACKEND_LIB_SYMLINK,
     FILE_TYPE_OPENGL_DATA,
+    FILE_TYPE_VULKANSC_ICD_JSON,
+    FILE_TYPE_SANDBOXUTILS_FILELIST_JSON,
     FILE_TYPE_MAX
 } PackageEntryFileType;
 
@@ -221,6 +223,7 @@ typedef struct __options {
     int compat32_files_packaged;
     int x_files_packaged;
     int vulkan_icd_json_packaged;
+    int vulkansc_icd_json_packaged;
     int concurrency_level;
     int skip_module_load;
     int skip_depmod;
@@ -251,6 +254,7 @@ typedef struct __options {
     char *compat32_chroot;
     char *compat32_prefix;
     char *compat32_libdir;
+    char *compat32_gbm_backend_dir;
 
     char *utility_prefix;
     char *utility_libdir;
@@ -315,6 +319,26 @@ typedef struct __options {
         int status_active;
         IndeterminateData *indeterminate_data;
     } ui;
+
+    struct {
+        unsigned int found_supported   :1;
+        unsigned int found_vga         :1;
+
+        int num_legacy;
+        int legacy[16];
+    } pci_devices;
+
+    struct {
+        unsigned int required                :1;
+        unsigned int supported_gpu_present   :1;
+        unsigned int unsupported_gpu_present :1;
+    } open_modules;
+
+    int num_ui_deferred_messages;
+    struct {
+        int level;
+        char *message;
+    } *ui_deferred_messages;
 } Options;
 
 typedef enum {
